Index: Source/core/inspector/AsyncCallChainMap.h |
diff --git a/Source/core/inspector/AsyncCallChainMap.h b/Source/core/inspector/AsyncCallChainMap.h |
index 0e992eae45d7ee5baf64d2ad9f34adc350560dc2..ba7e98c0bc704fa032cc1ee3dd156549f1e48efe 100644 |
--- a/Source/core/inspector/AsyncCallChainMap.h |
+++ b/Source/core/inspector/AsyncCallChainMap.h |
@@ -26,10 +26,17 @@ public: |
~AsyncCallChainMap() |
{ |
- // Verify that this object has been explicitly cleared already. |
- ASSERT(!m_debuggerAgent); |
+ // Verify that this object has been explicitly disposed. |
+ ASSERT(hasBeenDisposed()); |
} |
+#if ENABLE(ASSERT) |
+ bool hasBeenDisposed() const |
+ { |
+ return !m_debuggerAgent; |
+ } |
+#endif |
+ |
void dispose() |
{ |
clear(); |